# towles-tool

[![Release](https://img.shields.io/github/v/release/ChrisTowles/towles-tool)](https://img.shields.io/github/v/release/ChrisTowles/towles-tool)
[![Build status](https://img.shields.io/github/actions/workflow/status/ChrisTowles/towles-tool/main.yml?branch=main)](https://github.com/ChrisTowles/towles-tool/actions/workflows/main.yml?query=branch%3Amain)
[![codecov](https://codecov.io/gh/ChrisTowles/towles-tool/branch/main/graph/badge.svg)](https://codecov.io/gh/ChrisTowles/towles-tool)
[![Commit activity](https://img.shields.io/github/commit-activity/m/ChrisTowles/towles-tool)](https://img.shields.io/github/commit-activity/m/ChrisTowles/towles-tool)
[![License](https://img.shields.io/github/license/ChrisTowles/towles-tool)](https://img.shields.io/github/license/ChrisTowles/towles-tool)

Helper cli commands from a developer

- **Github repository**: <https://github.com/ChrisTowles/towles-tool/>
- **Documentation** <https://ChrisTowles.github.io/towles-tool/>


## Installation

These instructions are to install globally using [uv](https://docs.astral.sh/uv/getting-started/installation/#standalone-installer).


### Install from pypi

https://pypi.org/project/towles-tool/

```bash

uv tool install towles-tool

```
Testing the installation was successful:
```bash
towles-tool --version

```
Or using the shortened alias `tt`

```bash
tt --version
```
## Development

Follow the instructions in [docs/development-environment.md](docs/development-environment.md) to set up your development environment.


## Documentation

- [Releasing a new version](docs/how-to-release.md)

## Brother's Contract

- 2025-06-07: Patrick agreed that while he loves rust. he can not add it to this project until he first addes and extendsion system to do it first.


## Blog Posts

Chris Also keeps a blog where he writes about his learnings. Check it out here: https://chris.towles.dev/ and follow me on twitter: https://twitter.com/Chris_Towles
